'use strict';

import Reflux from "reflux";
import assign from "object-assign";

import Actions from "../actions/Actions";

/**
 * Stores state of components.
 *
 * Useful for example when a component is going to be dismounted, but we want to remember (a part of) its state for the
 * next time it is rendered.
 */
export default class ComponentStateStore extends Reflux.Store {

    constructor() {
        super();
        this.state = {};
        this.listenTo(Actions.rememberComponentState, this.onRememberComponentState);
        this.listenTo(Actions.resetComponentState, this.onResetComponentState);
    }

    onRememberComponentState(compId, state) {
        const change = {};
        change[compId] = assign({}, state);
        this.setState(change);
    }

    onResetComponentState(compId) {
        const change = {};
        change[compId] = undefined;
        this.setState(change);
    }
}
